@@ -30,9 +30,9 @@ def is_prime(x: int):
 
 def find_prime_until(x: int):
     """
-    return all prime below int x.
+    return all prime less than int x.
     :param x: (int)
-    :return: (list) all prime below int x
+    :return: (list) all prime less than int x
     """
     if x < 2:
         return []
@@ -211,7 +211,7 @@ def least_common_multiple_in_list(a: list):
     return least_common_multiple_in_list(_list)
 
 
-def greatest_common_divisor_with_exp(a: int, b: int):
+def greatest_common_divisor_with_coefficient(a: int, b: int):
     """
     calc the greatest common divisor between a and b, and find two numbers x, y to fit formula:
     a * x + b * y = the greatest common divisor.
@@ -222,7 +222,7 @@ def greatest_common_divisor_with_exp(a: int, b: int):
     if b == 0:
         return a, 1, 0
     else:
-        __greatest_common_divisor, __x, __y = greatest_common_divisor_with_exp(b, a % b)
+        __greatest_common_divisor, __x, __y = greatest_common_divisor_with_coefficient(b, a % b)
         _x = __y
         _y = __x - (a // b) * __y
         return __greatest_common_divisor, _x, _y
@@ -237,4 +237,4 @@ def inverse(a: int, n: int):
     :return: (int) x
     """
     assert greatest_common_divisor(a, n) == 1
-    return greatest_common_divisor_with_exp(a, n)[1] % n
+    return greatest_common_divisor_with_coefficient(a, n)[1] % n
